import * as Phoenix from "phoenix";
export declare class Conversation {
    private audioContext;
    private audioInterval;
    private audioSendInterval;
    private audioSourceConstraints;
    private channel;
    private conversationId;
    private messageList;
    private pubsub;
    private recorder;
    private socket;
    private speakerList;
    private wrapper;
    /**
     * @ignore
     */
    constructor(conversationId: string, identifier: string, socket: Phoenix.Socket, options: Required<ConversationOptions>);
    /**
     * Get the recording status of the conversation.
     *
     * @category Recording
     * @example
     * ```javascript
     * const uhlive = new Uhlive("my-token");
     * uhlive
     *     .join("my-conversation")
     *     .isRecording(); // true
     * ```
     *
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * uhlive
     *     .join("my-conversation", {readonly: true})
     *     .isRecording(); // false
     * ```
     */
    isRecording(): boolean;
    /**
     * @ignore
     */
    leave(): void;
    /**
     * Subscribe to Conversation `onClose` event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const conversation = uhlive.join("test");
     * conversation.onClose(() => {
     *   // Choose what to do when the conversation is closed.
     * })
     * ```
     */
    onClose(callback: () => void): Conversation;
    /**
     * This event is triggered when a number entity has been found.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onEntityNumberFound((entity) => {
     *     // Do something with `entity`...
     * });
     * ```
     */
    onEntityNumberFound(callback: (entity: EntityNumber) => void): Conversation;
    /**
     * This event is triggered when an ordinal entity has been found.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onEntityOrdinalFound((entity) => {
     *     // Do something with `entity`...
     * });
     * ```
     */
    onEntityOrdinalFound(callback: (entity: EntityOrdinal) => void): Conversation;
    /**
     * Subscribe to Conversation `onError` event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const conversation = uhlive.join("test");
     * conversation.onError((msg) => console.log(msg))
     * ```
     */
    onError(callback: (payload: any) => void): Conversation;
    /**
     * The `onSegmentDecoded` event is triggered when a final transcript is received.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onSegmentDecoded((transcript) => {
     *     // Do something with `transcript`...
     * });
     * ```
     */
    onSegmentDecoded(callback: (transcript: SegmentDecoded) => void): Conversation;
    /**
     * The `speaker_left` event is triggered when a speaker leaves, or more abruptly, closes its connection. This event is published after all remaining transcript events of this speaker have been published. Note that users connected in read-only mode (observers) don't emit any event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onSpeakerLeft((speaker) => {
     *     // Do something with `speaker`...
     * });
     * ```
     */
    onSpeakerLeft(callback: (speaker: string) => void): Conversation;
    /**
     * The `words_decoded` event is triggered when an interim transcript is received. Following `words_decoded` events for the same audio are susceptible to be different, until a final transcript is sent with the `segment_decoded` event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onWordsDecoded((transcript) => {
     *     // Do something with `transcript`...
     * });
     * ```
     */
    onWordsDecoded(callback: (transcript: WordsDecoded) => void): Conversation;
    private addEntityToMessage;
    private addOrUpdateMessage;
    private addSpeaker;
    private askForPermissions;
    private sendMessage;
    private socketSend;
    private startRecording;
    private stopRecording;
    private validateConstructorParameters;
}
export declare enum ConversationEvent {
    NumberFound = "NumberFound",
    OrdinalFound = "OrdinalFound",
    SegmentDecoded = "SegmentDecoded",
    WordsDecoded = "WordsDecoded"
}
/**
 * Optional parameters for Conversation class constructor.
 */
export interface ConversationOptions {
    /**
     * Specify on which Enrich events we want to unsubscribe to.
     */
    ignoreEvents?: ConversationEvent[];
    /**
     * Send interim segments as well as the final segments.
     */
    interim_results?: boolean;
    /**
     * Specify which model to use to decode the audio.
     */
    model?: string;
    /**
     * Set to `true` if you don't want to send audio but only read. Note that in read-only mode, no events will be emitted.
     */
    readonly?: boolean;
    /**
     * Rescore the transcript result for better results.
     */
    rescoring?: boolean;
    /**
     * Speaker identifier.
     */
    speaker?: string;
    /**
     * Specify in which element the conversation should be displayed.
     */
    wrapper?: string;
}
export interface EntityAnnotation {
    /**
     * Well-formatted, localized decimal form of the number or ordinal.
     */
    canonical: string;
    /**
     * The transcript of the number or ordinal.
     */
    original: string;
    /**
     * The value or rank for an ordinal.
     */
    value: number;
}
export interface EntityNumber {
    /**
     * Annotation to enrich the transcript.
     */
    annotation: EntityAnnotation;
    /**
     * Timestamp of the end of the entity, in milliseconds.
     */
    end: number;
    /**
     * Lang of the entity.
     */
    lang: string;
    /**
     * Length of the entity, in milliseconds.
     */
    length: number;
    /**
     * The id of the speaker.
     */
    speaker: string;
    /**
     * Timestamp of the start of the entity, in milliseconds.
     */
    start: number;
}
export interface EntityOrdinal {
    /**
     * Annotation to enrich the transcript.
     */
    annotation: EntityAnnotation;
    /**
     * Timestamp of the end of the entity, in milliseconds.
     */
    end: number;
    /**
     * Lang of the entity.
     */
    lang: string;
    /**
     * Length of the entity, in milliseconds.
     */
    length: number;
    /**
     * The id of the speaker.
     */
    speaker: string;
    /**
     * Timestamp of the start of the entity, in milliseconds.
     */
    start: number;
}
/**
 * @ignore
 */
interface Decoding {
    /**
     * Confidence of the decoding, from 0 to 1.
     */
    confidence: number;
    /**
     * Timestamp of the end of the word, in milliseconds.
     */
    end: number;
    /**
     * Length of the word, in milliseconds.
     */
    length: number;
    /**
     * Timestamp of the beginning of the word, in milliseconds.
     */
    start: number;
}
export interface SegmentDecodedWord extends Decoding {
    /**
     * The decoded word.
     */
    word: string;
}
export interface WordsDecoded extends Decoding {
    /**
     * Speech language. 2 letter ISO code or `default`.
     */
    lang: string;
    /**
     * Technical name of ASR model. You can find the list of available models [here](https://docs.allo-media.net/live-api/asr-models/#available-asr-models).
     */
    model: string;
    /**
     * The id of the speaker.
     */
    speaker: string;
    /**
     * Concatenated words of the segment.
     */
    transcript: string;
    /**
     * Identifies the utterance this event transcribes.
     */
    utterance_id: number;
    /**
     * Words decoded for the segment.
     */
    words: SegmentDecodedWord[];
}
export interface SegmentDecoded extends Decoding {
    /**
     * Speech language. 2 letter ISO code or `default`.
     */
    lang: string;
    /**
     * Technical name of ASR model. You can find the list of available models [here](https://docs.allo-media.net/live-api/asr-models/#available-asr-models).
     */
    model: string;
    /**
     * The id of the speaker.
     */
    speaker: string;
    /**
     * Concatenated words of the segment.
     */
    transcript: string;
    /**
     * Identifies the utterance this event transcribes.
     */
    utterance_id: number;
    /**
     * Words decoded for the segment.
     */
    words: SegmentDecodedWord[];
}
export {};
